#ifndef SYMFONIEVOLUMEDIALOG_H
#define SYMFONIEVOLUMEDIALOG_H

#include <QDialog>

namespace Ui {
    class SymfonieVolumeDialog;
}

class SymfonieVolumeDialog : public QDialog {
    Q_OBJECT
public:
    SymfonieVolumeDialog(QWidget *parent = 0);
    ~SymfonieVolumeDialog();

    QPushButton*  getShowSeekbarButton();

protected:
    void changeEvent(QEvent *e);

Q_SIGNALS:
    /**
      * 0.1 - 40
      */
    void speedChangedSignal(double speed);
    void showSeekbarToggledSignal(bool);

private Q_SLOTS:
    void speedSliderChangedSlot(double);


private:
    Ui::SymfonieVolumeDialog *ui;
};

#endif // SYMFONIEVOLUMEDIALOG_H
